@@ -1,9 +1,11 @@
 package App::relpath;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-15'; # DATE
+our $DATE = '2023-11-20'; # DATE
 our $DIST = 'App-relpath'; # DIST
-our $VERSION = '0.051'; # VERSION
+our $VERSION = '0.052'; # VERSION
 
 1;
 # ABSTRACT: Return the relative pathname
@@ -20,18 +22,12 @@ App::relpath - Return the relative pathname
 
 =head1 VERSION
 
-This document describes version 0.051 of App::relpath (from Perl distribution App-relpath), released on 2021-07-15.
+This document describes version 0.052 of App::relpath (from Perl distribution App-relpath), released on 2023-11-20.
 
 =head1 SYNOPSIS
 
 See the command-line script L<relpath>.
 
-=head1 CONTRIBUTOR
-
-=for stopwords Steven Haryanto
-
-Steven Haryanto <sharyanto@cpan.org>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-relpath>.
@@ -40,14 +36,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-relpat
 
 Source repository is at L<https://github.com/perlancar/perl-App-relpath>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-relpath>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<App::realpath>, L<App::quickabspath>
@@ -56,11 +44,43 @@ L<App::realpath>, L<App::quickabspath>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2015, 2014 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-relpath>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
